==> owncloud-8.2.2p3.tgz: owncloud/apps/files/l10n/es_MX.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Error desconocido",
    "Could not move %s - File with this name already exists" : "No se pudo mover %s - Ya existe un archivo con ese nombre.",
    "Could not move %s" : "No se pudo mover %s",
    "The name %s is already used in the folder %s. Please choose a different name." : "El nombre %s ya está en uso por la carpeta %s. Por favor elija uno diferente.",
    "Error when creating the file" : "Error al crear el archivo",
    "Error when creating the folder" : "Error al crear la carpeta.",
    "Unable to set upload directory." : "Incapaz de crear directorio de subida.",
    "Invalid Token" : "Token Inválido",
    "No file was uploaded. Unknown error" : "No se subió ningún archivo. Error desconocido",
    "There is no error, the file uploaded with success" : "No hubo ningún problema, el archivo se subió con éxito",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "El archivo subido sobrepasa la directiva 'upload_max_filesize' en php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa la directiva 'MAX_FILE_SIZE' especificada en el formulario HTML",
    "The uploaded file was only partially uploaded" : "El archivo subido fue sólo subido parcialmente",
    "No file was uploaded" : "No se subió ningún archivo",
    "Missing a temporary folder" : "Falta la carpeta temporal",
    "Failed to write to disk" : "Falló al escribir al disco",
    "Not enough storage available" : "No hay suficiente espacio disponible",
    "Upload failed. Could not find uploaded file" : "Actualización fallida. No se pudo encontrar el archivo subido",
    "Upload failed. Could not get file info." : "Actualización fallida. No se pudo obtener información del archivo.",
    "Invalid directory." : "Directorio inválido.",
    "Files" : "Archivos",
    "Favorites" : "Favoritos",
    "Home" : "Particular",
    "Close" : "Cerrar",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
    "Upload cancelled." : "Subida cancelada.",
    "Could not get result from server." : "No se pudo obtener respuesta del servidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La subida del archivo está en proceso. Si sale de la página ahora, la subida será cancelada.",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Renombrar",
    "Delete" : "Eliminar",
    "Details" : "Detalles",
    "Pending" : "Pendiente",
    "Error moving file" : "Error moviendo archivo",
    "Error" : "Error",
    "{new_name} already exists" : "{new_name} ya existe",
    "Could not rename file" : "No se pudo renombrar el archivo",
    "Could not create file" : "No se pudo crear el archivo",
    "Could not create folder" : "No se pudo crear la carpeta",
    "Error deleting file." : "Error borrando el archivo.",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "You don’t have permission to upload or create files here" : "No tienes permisos para subir o crear archivos aquí.",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "Your storage is full, files can not be updated or synced anymore!" : "Su almacenamiento está lleno, ¡los archivos no se actualizarán ni sincronizarán más!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su almacenamiento está casi lleno ({usedSpacePercent}%)",
    "Favorite" : "Favorito",
    "Upload" : "Subir archivo",
    "Text file" : "Archivo de texto",
    "Folder" : "Carpeta",
    "New folder" : "Nueva carpeta",
    "You created %1$s" : "Has creado %1$s",
    "You changed %1$s" : "Has cambiado %1$s",
    "You deleted %1$s" : "Has eliminado %1$s",
    "%s could not be renamed" : "%s no pudo ser renombrado",
    "File handling" : "Administración de archivos",
    "Maximum upload size" : "Tamaño máximo de subida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "Settings" : "Ajustes",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Utilice esta dirección para <a href=\"%s\" target=\"_blank\">acceder a sus archivos vía WebDAV</a>",
    "Cancel upload" : "Cancelar subida",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "Files are being scanned, please wait." : "Los archivos están siendo escaneados,  por favor espere."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.4.tgz: owncloud/apps/files/l10n/es_MX.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Error desconocido",
    "Unable to set upload directory." : "Incapaz de crear directorio de subida.",
    "Invalid Token" : "Token Inválido",
    "No file was uploaded. Unknown error" : "No se subió ningún archivo. Error desconocido",
    "There is no error, the file uploaded with success" : "No hubo ningún problema, el archivo se subió con éxito",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "El archivo subido sobrepasa la directiva 'upload_max_filesize' en php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa la directiva 'MAX_FILE_SIZE' especificada en el formulario HTML",
    "The uploaded file was only partially uploaded" : "El archivo subido fue sólo subido parcialmente",
    "No file was uploaded" : "No se subió ningún archivo",
    "Missing a temporary folder" : "Falta la carpeta temporal",
    "Failed to write to disk" : "Falló al escribir al disco",
    "Not enough storage available" : "No hay suficiente espacio disponible",
    "Upload failed. Could not find uploaded file" : "Actualización fallida. No se pudo encontrar el archivo subido",
    "Upload failed. Could not get file info." : "Actualización fallida. No se pudo obtener información del archivo.",
    "Invalid directory." : "Directorio inválido.",
    "Files" : "Archivos",
    "Home" : "Particular",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Upload cancelled." : "Subida cancelada.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
    "Could not get result from server." : "No se pudo obtener respuesta del servidor.",
    "Uploading..." : "Subiendo...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La subida del archivo está en proceso. Si sale de la página ahora, la subida será cancelada.",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Renombrar",
    "Delete" : "Eliminar",
    "Unshare" : "Dejar de compartir",
    "Details" : "Detalles",
    "Pending" : "Pendiente",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "You don’t have permission to upload or create files here" : "No tienes permisos para subir o crear archivos aquí.",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "Your storage is full, files can not be updated or synced anymore!" : "Su almacenamiento está lleno, ¡los archivos no se actualizarán ni sincronizarán más!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su almacenamiento está casi lleno ({usedSpacePercent}%)",
    "Favorite" : "Favorito",
    "Folder" : "Carpeta",
    "New folder" : "Nueva carpeta",
    "Upload" : "Subir archivo",
    "You created %1$s" : "Has creado %1$s",
    "You changed %1$s" : "Has cambiado %1$s",
    "You deleted %1$s" : "Has eliminado %1$s",
    "File handling" : "Administración de archivos",
    "Maximum upload size" : "Tamaño máximo de subida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "Settings" : "Ajustes",
    "WebDAV" : "WebDAV",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "Text file" : "Archivo de texto"
},
"nplurals=2; plural=(n != 1);");
